% method of class @signal
% function sig=addtimevalue(sig,time,val)
%usage: sig=addtimevalue(sig,time,val)
% adds the double time value "time" to "val"
%
%   INPUT VALUES:
%       sig:  original @signal
%       time: time in seconds, where the value is added
%       val: value, that is added at time
%    
%   RETURN VALUE:
%       sig: @signal
%
% (c) 2003-2008, University of Cambridge, Medical Research Council 
% Maintained by Tom Walters (tcw24@cam.ac.uk), written by Stefan Bleeck (stefan@bleeck.de)
% http://www.pdn.cam.ac.uk/cnbh/aim2006
% $Date: 2008-06-10 18:00:16 +0100 (Tue, 10 Jun 2008) $
% $Revision: 585 $

function sig=addtimevalue(sig,time,val)

nr=time2bin(sig,time);
sig.werte(nr)=sig.werte(nr)+val;